@@ -1,5 +1,5 @@
 /*  Zcmp - decompress and compare two files byte by byte
-    Copyright (C) 2010, 2011, 2012, 2013 Antonio Diaz Diaz.
+    Copyright (C) 2010, 2011, 2012, 2013, 2014 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -36,12 +36,8 @@
 #endif
 
 #include "arg_parser.h"
-#include "zutils.h"
 #include "rc.h"
-
-#if CHAR_BIT != 8
-#error "Environments where CHAR_BIT != 8 are not supported."
-#endif
+#include "zutils.h"
 
 #ifndef LLONG_MAX
 #define LLONG_MAX  0x7FFFFFFFFFFFFFFFLL
@@ -52,7 +48,6 @@ namespace {
 
 #include "zcmpdiff.cc"
 
-
 void show_help()
   {
   std::printf( "Zcmp compares two files (\"-\" means standard input), and if they\n"
@@ -246,12 +241,12 @@ int cmp( const long long max_size, const int infd[2],
         }
       }
 
-    buffer0[rd[0]] = ~buffer1[rd[0]];	// sentinels for the block compare
-    buffer1[rd[1]] = ~buffer0[rd[1]];
+    const int min_rd = std::min( rd[0], rd[1] );
+    buffer0[min_rd] = 0;		// sentinels for the block compare
+    buffer1[min_rd] = 1;
 
     int first_diff = block_compare( buffer0, buffer1, &line_number );
     byte_number += first_diff;
-    const int min_rd = std::min( rd[0], rd[1] );
 
     if( first_diff < min_rd )
       {
@@ -301,7 +296,7 @@ int cmp( const long long max_size, const int infd[2],
       {
       if( verbosity >= 0 )
         std::fprintf( stderr, "%s: EOF on %s\n",
-                      util_name, filenames[rd[1]<rd[0]].c_str() );
+                      program_name, filenames[rd[1]<rd[0]].c_str() );
         return 1;
       }
     if( min_rd != buffer_size ) break;
@@ -323,7 +318,7 @@ int main( const int argc, const char * const argv[] )
   int format_types[2] = { -1, -1 };
   bool print_bytes = false;
   invocation_name = argv[0];
-  util_name = "zcmp";
+  program_name = "zcmp";
 
   const Arg_parser::Option options[] =
     {
@@ -443,7 +438,7 @@ int main( const int argc, const char * const argv[] )
   for( int i = 0; i < 2; ++i )
     {
     if( close( infd[i] ) != 0 )
-      { show_close_error( "data feeder" ); retval = 2; }
+      { show_close_error(); retval = 2; }
     if( filenames[i] != "-" && close( old_infd[i] ) != 0 )
       {
       show_error2( "Can't close input file", filenames[i].c_str() );
