@@ -1,5 +1,5 @@
 /*  Common code for Zcmp and Zdiff
-    Copyright (C) 2010, 2011, 2012, 2013 Antonio Diaz Diaz.
+    Copyright (C) 2010, 2011, 2012, 2013, 2014 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -15,10 +15,8 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#ifdef O_BINARY
-const int o_binary = O_BINARY;
-#else
-const int o_binary = 0;
+#ifndef O_BINARY
+#define O_BINARY 0
 #endif
 
 struct { const char * from; const char * to; } const known_extensions[] = {
@@ -36,7 +34,7 @@ struct { const char * from; const char * to; } const known_extensions[] = {
 
 int open_instream( const std::string & input_filename )
   {
-  int infd = open( input_filename.c_str(), O_RDONLY | o_binary );
+  const int infd = open( input_filename.c_str(), O_RDONLY | O_BINARY );
   if( infd < 0 )
     show_error2( "Can't open input file", input_filename.c_str() );
   return infd;
@@ -53,13 +51,13 @@ int open_other_instream( std::string & name )
       {
       name.resize( name.size() - from.size() );
       name += known_extensions[i].to;
-      return open( name.c_str(), O_RDONLY | o_binary );
+      return open( name.c_str(), O_RDONLY | O_BINARY );
       }
     }
   for( int i = 0; i < num_formats; ++i )
     {					// search compressed version
     const std::string s( name + simple_extensions[format_order[i]] );
-    const int infd = open( s.c_str(), O_RDONLY | o_binary );
+    const int infd = open( s.c_str(), O_RDONLY | O_BINARY );
     if( infd >= 0 ) { name = s; return infd; }
     }
   return -1;
